/*
 *  blantantly copied from linux/kernel/printk.c
 *
 *  Copyright (C) 1991, 1992  Linus Torvalds
 *
 *  by yhlu moved from arch/ppc/lib/printk_init.c, removed the global variable console_loglevel
 */
#include <stdarg.h>
#include <console/loglevel.h>

/* printk's without a loglevel use this.. */
#define DEFAULT_MESSAGE_LOGLEVEL 4 /* BIOS_WARNING */

/* Keep together for sysctl support */
/* Using an global varible can cause problem when we reset the stack from cache as ram to ram*/
#if 0
int console_loglevel = DEFAULT_CONSOLE_LOGLEVEL;
#else
#define console_loglevel ASM_CONSOLE_LOGLEVEL
#endif

extern int vtxprintf(void (*)(unsigned char), const char *, va_list);
extern void uart8250_tx_byte(unsigned, unsigned char);
#if CONFIG_USBDEBUG_DIRECT
extern void usbdebug_direct_tx_byte(unsigned char);
extern void usbdebug_direct_ram_tx_byte(unsigned char);
#endif

void console_tx_byte(unsigned char byte)
{
	if (byte == '\n') {
		uart8250_tx_byte(TTYS0_BASE, '\r');
#if CONFIG_USBDEBUG_DIRECT
		usbdebug_direct_tx_byte('\r');
#endif
	}
	uart8250_tx_byte(TTYS0_BASE, byte);
#if CONFIG_USBDEBUG_DIRECT
	usbdebug_direct_tx_byte(byte);
#endif
}

int do_printk(int msg_level, const char *fmt, ...)
{
	va_list args;
	int i;

	if (msg_level >= console_loglevel) {
		return 0;
	}

	va_start(args, fmt);
	i = vtxprintf(console_tx_byte, fmt, args);
	va_end(args);

	return i;
}
#if CONFIG_USBDEBUG_DIRECT
void console_ram_tx_byte(unsigned char byte)
{
	if (byte == '\n') {
		uart8250_tx_byte(TTYS0_BASE, '\r');
		usbdebug_direct_ram_tx_byte('\r');
	}
	uart8250_tx_byte(TTYS0_BASE, byte);
	usbdebug_direct_ram_tx_byte(byte);
}

int do_printk_ram(int msg_level, const char *fmt, ...)
{
	va_list args;
	int i;

	if (msg_level >= console_loglevel) {
		return 0;
	}

	va_start(args, fmt);
	i = vtxprintf(console_ram_tx_byte, fmt, args);
	va_end(args);

	return i;
}
#endif

